bomcheck help 2

# bomcheck help (page 2)

1. How to extract BOMs as Excel files from SyteLine

1. Single level SL BOMs
2. Multilevel SL BOMs

2. How to extract BOMs as Excel files from SolidWorks

1. Single level SW BOMs
2. Multilevel SW BOMs (for advanced users)

1. Managing missing part no. descriptions
2. Managing missing part nos.
3. Limiting the BOMs to analyze

## 1. How to extract BOMs as Excel files from SyteLine

### 1a. Single level SL BOMs

To extract a single level BOM from SyteLine, go to the Item, go to Current Materials, right click on the BOM and pick To Excel

### 1b. Multilevel level SL BOMs

Extracting a multilevel BOM from SyteLine requires two steps. First go to Indented Current BOM Report, enter the Item no., pick Report Option > DataView, then click Preview.
Next, from the window that pops up, click the gear icon and then choose Send To > Excel. (Careful... no not click the "Level" column header. You'll resort your BOM.)

It your BOM is empty, you may have to go back to step 1b and click the Print Only Zero Level Items button. Sometimes this button needs to be clicked, sometimes not.

## 2. Extract BOMs as Excel files from SolidWorks

### 2a. Single level SW BOMs

To extract a single level BOM from SolidWorks, open up the drawing where your BOM is located, right click on the BOM, and pick Save As...

### 2b. Multilevel level SW BOMs (for advanced users)

To extract a multilevel BOM from SolidWorks, open up the assembly model and insert a BOM into it. Have both Lchk and LENGTH columns showing in order to verify pipe lengths, and have Part no, Description, Qty, and Item no. columns showing. (Column order is irrelavent.) Make sure the BOM type is Indented, Detailed numbering, and Detailed cut list. I.e. make sure all are activated. Then right click on the BOM and pick Save As...

### 2b-i. Managing missing part no. descriptions

When you first create a SW BOM (step 2b), you may see some part nos. that do not have descriptions; i.e. the fields are blank. In which case it means you forgot to enter some part numbers. Therefore you should pull up the part files and add the descripions. However for welded parts such as bases and brackets, you will often see that desriptions are missing. This has to do with how Custom Properties differ between a SW Cutlist and a SW BOM. Cutlist items have Custom Properties Part Number and Description who's values show in a Cutlist BOM. SW BOMs on the other hand have Part Number and Description1 instead. So if you want your weldment descriptions to show in the bomcheck, you need to enter a Description1 for those cultlist items with missing descriptions. However this isn't necessary. Unless the weldment templates that generated weldments are incorrect, which is highly unlikely, then you need not fill in these values. So then, you should have some confidence that desriptions are correct. When you run bomcheck the empty description field will be filled in with ----- sw_description_missing -----.

### 2b-ii. Managing missing part nos.

Sometimes you'll see missing part numbers that are a result of something that was not modeled correctly; e.g. some part in a lower level subassembly that should have been "excluded" from the BOM. You can open up the problem part and fix the problem. This is the best thing to do, but this takes time. Another option is to use the step shown in 3a to hide the problem. Yet another option is to do nothing. If you use the "do nothing" approach, when you run bomcheck, missing part numbers will be filled in with PN_MISSING.

If you don't want to see PN_MISSING in your bomcheck results, you can add it to your drop list. The drop list is discussed in bomcheck's help sections 1 and 2.

### 2b-iii. Limiting the BOMs to analyze.

If you have a large BOM to analyze, you may wish to omit some subassemblies from the BOM analysis, not because it will slow bomcheck down too much, but because you wish to avoid unnecessary clutter of text that is output. To do this go to the BOM and click on it's left side and then click on the three arrows that appear on the middle left side of the BOM. Along side the subassemblies you will see + and - signs. Click on these to expand or collapse subasseblies. Collapsed subassemblies will not be analyzed.